fn exact_source_policy(
binding: &SourceBinding,
control: &IndexWorkControl,
) -> Result<(String, String), CliError>Expand description
Capture the scanner contract and dynamic policy for one exact source binding.
fn exact_source_policy(
binding: &SourceBinding,
control: &IndexWorkControl,
) -> Result<(String, String), CliError>Capture the scanner contract and dynamic policy for one exact source binding.