fn source_policy_paths(
plan: &ScanRuntimePlan,
control: &IndexWorkControl,
) -> Result<Vec<PathBuf>, CliError>Expand description
Collect every scanner policy input whose state contributes to source selection.
fn source_policy_paths(
plan: &ScanRuntimePlan,
control: &IndexWorkControl,
) -> Result<Vec<PathBuf>, CliError>Collect every scanner policy input whose state contributes to source selection.