fn source_policy_witness(
plan: &ScanRuntimePlan,
control: &IndexWorkControl,
) -> Result<String, CliError>Expand description
Hash the bounded external inputs that may change the scanner’s source selection.
fn source_policy_witness(
plan: &ScanRuntimePlan,
control: &IndexWorkControl,
) -> Result<String, CliError>Hash the bounded external inputs that may change the scanner’s source selection.